<?php

/**
 * Contao Open Source CMS
 *
 * Copyright (c) 2005-2013 Leo Feyer
 *
 * @package News
 * @link    https://contao.org
 * @license http://www.gnu.org/licenses/lgpl-3.0.html LGPL
 */


/**
 * Run in a custom namespace, so the class can be replaced
 */
namespace Contao;


/**
 * Class ModuleProductList
 *
 * Front end module "product list".
 * @copyright  Leo Feyer 2005-2013
 * @author     Leo Feyer <https://contao.org>
 * @package    product
 */
class ProductCategory extends \Module
{
	/**
	 * Template
	 * @var string
	 */
	protected $strTemplate = 'mod_navigation';


	public function generate()
	{
		if (TL_MODE == 'BE')
		{
			$objTemplate = new \BackendTemplate('be_wildcard');

			$objTemplate->wildcard = '### ' . utf8_strtoupper($GLOBALS['TL_LANG']['FMD']['productcategories'][0]) . ' ###';
			$objTemplate->title = $this->headline;
			$objTemplate->id = $this->id;
			$objTemplate->link = $this->name;
			$objTemplate->href = 'contao/main.php?do=themes&amp;table=tl_module&amp;act=edit&amp;id=' . $this->id;

			return $objTemplate->parse();
		}

		// Return if there are no categories
		$this->product_category = deserialize($this->product_category);
		if (!is_array($this->product_category) || !count($this->product_category))
		{
			return '';
		}

		return parent::generate();
	}


	protected function compile()
	{
		// Jump to current page
		global $objPage;
		$arrPage = array('id'=>$objPage->id, 'alias'=>$objPage->alias);

		// Overwrite target with jumpTo page
		if ($this->jumpTo)
		{
			$objJumpTo = $this->Database->prepare("SELECT id,alias FROM tl_page WHERE id=?")->limit(1)->execute($this->jumpTo);

			if ($objJumpTo->numRows)
			{
				$arrPage = $objJumpTo->row();
			}
		}

		$c = 0;
		$arrCategories = array();
		$objCategories = $this->Database->execute("SELECT * FROM tl_product_category WHERE id IN (" . implode(',', $this->product_category) . ") ORDER BY title ASC");

		$objTemplate = new FrontendTemplate($this->navigationTpl);

		$objTemplate->type = get_class($this);
		$objTemplate->level = 'level_0';

		if (strlen($this->Input->get('items')))
		{
			$objNews = $this->Database->prepare("SELECT * FROM tl_news WHERE pid IN (" . implode(',', deserialize($this->news_archives, true)) . ") AND alias=?")->execute($this->Input->get('items'));
		}

		while( $objCategories->next() )
		{
			$blnNews = ($objNews && $objNews->numRows && $objNews->category == $objCategories->id) ? true : false;

			$arrCategories[] = array
			(
				'isActive'		=> ((\Input::get('category') == $objCategories->id || \Input::get('category') == $objCategories->alias || $blnNews) ? true : false),
				'subitems'		=> '',
				'class'			=> ('category' . ($c==0 ? ' first' : '') . ($c+1==$objCategories->numRows ? ' last' : '')),
				'pageTitle'		=> specialchars($objCategories->title),
				'title'			=> specialchars($objCategories->title),
				'link'			=> $objCategories->title,
				'href'			=> $this->generateFrontendUrl($arrPage, '/category/'.(strlen($objCategories->alias) ? $objCategories->alias : $objCategories->id)),
				'alias'			=> $objCategories->id,
				'nofollow'		=> (strncmp($objSubpages->robots, 'noindex', 7) === 0),
				'target'		=> '',
				'description'	=> '',
				'accesskey'		=> '',
				'tabindex'		=> '',
			);

			$c++;
		}

		$objTemplate->items = $arrCategories;

		$request = ampersand($this->Environment->request, true);

		if ($request == 'index.php')
		{
			$request = '';
		}

		$this->Template->request = $request;
		$this->Template->skipId = 'skipNavigation' . $this->id;
		$this->Template->skipNavigation = specialchars($GLOBALS['TL_LANG']['MSC']['skipNavigation']);
		$this->Template->items = count($arrCategories) ? $objTemplate->parse() : '';
	}
}
