<?php

/**
 * Contao Open Source CMS
 *
 * Copyright (c) 2005-2014 Leo Feyer
 *
 * @package   movie_list
 * @author    Fast End Media | Christian Schmidt <schmidt@fast-end-media.de>
 * @license   LGPL
 * @copyright Fast End Media 2014 <http://www.fast-end-media.de>
 */


/**
 * Run in a custom namespace, so the class can be replaced
 */
namespace Contao;

class ModuleMovieList extends \ModuleMovie
{
	/**
	 * Template
	 * @var string
	 */
	protected $strTemplate = 'mod_movielist';

	/**
	 * Display a wildcard in the back end
	 * @return string
	 */
	public function generate()
	{
		if (TL_MODE == 'BE')
		{
			$objTemplate = new \BackendTemplate('be_wildcard');
			$objTemplate->wildcard = '### ' . utf8_strtoupper($GLOBALS['TL_LANG']['FMD']['movielist'][0]) . ' ###';
			$objTemplate->title = $this->headline;
			$objTemplate->id = $this->id;
			$objTemplate->link = $this->name;
			$objTemplate->href = 'contao/main.php?do=themes&amp;table=tl_module&amp;act=edit&amp;id=' . $this->id;
			return $objTemplate->parse();
		}
    $this->movie_archives = $this->sortOutProtected(deserialize($this->movie_archives));
		// Return if there are no archives
		if (!is_array($this->movie_archives) || empty($this->movie_archives))
		{
			return '';
		}
		return parent::generate();
	}

	/**
	 * Generate the module
	 */
	protected function compile()
	{
		$offset = intval($this->skipFirst);
		$limit = null;
		$this->Template->articles = array();
		// Maximum number of items
		if ($this->numberOfItems > 0)
		{
			$limit = $this->numberOfItems;
		}
		// Handle featured movie
		if ($this->movie_featured == 'featured')
		{
			$blnFeatured = true;
		}
		elseif ($this->movie_featured == 'unfeatured')
		{
			$blnFeatured = false;
		}
		else
		{
			$blnFeatured = null;
		}
		// Get the total number of items
		$intTotal = \MovieModel::countPublishedByPids($this->movie_archives, $blnFeatured);
		if ($intTotal < 1)
		{
			$this->Template = new \FrontendTemplate('mod_movie_empty');
			$this->Template->empty = $GLOBALS['TL_LANG']['MSC']['emptyMovieList'];
			return;
		}
		$total = $intTotal - $offset;
    $this->Template->total = $total;
		// Split the results
		if ($this->perPage > 0 && (!isset($limit) || $this->numberOfItems > $this->perPage))
		{
			// Adjust the overall limit
			if (isset($limit))
			{
				$total = min($limit, $total);
			}
			// Get the current page
			$id = 'page_n' . $this->id;
			$page = \Input::get($id) ?: 1;
			// Do not index or cache the page if the page number is outside the range
			if ($page < 1 || $page > max(ceil($total/$this->perPage), 1))
			{
				global $objPage;
				$objPage->noSearch = 1;
				$objPage->cache = 0;
				// Send a 404 header
				header('HTTP/1.1 404 Not Found');
				return;
			}
			// Set limit and offset
			$limit = $this->perPage;
			$offset += (max($page, 1) - 1) * $this->perPage;
			// Overall limit
			if ($offset + $limit > $total)
			{
				$limit = $total - $offset;
			}
			// Add the pagination menu
			$objPagination = new \Pagination($total, $this->perPage, $GLOBALS['TL_CONFIG']['maxPaginationLinks'], $id);
			$this->Template->pagination = $objPagination->generate("\n  ");
		}
		//Find out sorting
		if (\Input::get('order_by'))
		{
      $getSortBy = \Input::get('order_by');
		}
		if($this->sortBy) {
      $t = 'tl_movie';
			if($this->sortBy == 'movie_name_asc' && !$getSortBy || $getSortBy == 'movie_name_asc') { $sortBy = "$t.name ASC"; }
			elseif($this->sortBy == 'movie_name_desc' && !$getSortBy || $getSortBy == 'movie_name_desc') { $sortBy = "$t.name DESC"; }
      elseif($this->sortBy == 'year_asc' && !$getSortBy || $getSortBy == 'year_asc') { $sortBy = "$t.year ASC"; }
			elseif($this->sortBy == 'year_desc' && !$getSortBy || $getSortBy == 'year_desc') { $sortBy = "$t.year DESC"; }
      elseif($this->sortBy == 'rating_asc' && !$getSortBy || $getSortBy == 'rating_asc') { $sortBy = "$t.rating ASC"; }
			elseif($this->sortBy == 'rating_desc' && !$getSortBy || $getSortBy == 'rating_desc') { $sortBy = "$t.rating DESC"; }
      elseif($this->sortBy == 'imdb_asc' && !$getSortBy || $getSortBy == 'imdb_asc') { $sortBy = "$t.imdb ASC"; }
			elseif($this->sortBy == 'imdb_desc' && !$getSortBy || $getSortBy == 'imdb_desc') { $sortBy = "$t.imdb DESC"; }
      else { $sortBy = "rand()"; }
			$arrOptions['order']  = $sortBy;
		}
		// Get the items
		if (isset($limit))
		{
			$objArticles = \MovieModel::findPublishedByPids($this->movie_archives, $blnFeatured, $limit, $offset, $arrOptions);
		}
		else
		{
			$objArticles = \MovieModel::findPublishedByPids($this->movie_archives, $blnFeatured, 0, $offset);
		}

		// No items found
		if ($objArticles === null)
		{
			$this->Template = new \FrontendTemplate('mod_movie_empty');
			$this->Template->empty = $GLOBALS['TL_LANG']['MSC']['emptyMovieList'];
		}
		else
		{
			$this->Template->articles = $this->parseArticles($objArticles);
		}
	}
}
