<?php

/**
 * Contao Open Source CMS
 *
 * Copyright (c) 2005-2014 Leo Feyer
 *
 * @package   movie_list
 * @author    Fast End Media | Christian Schmidt <schmidt@fast-end-media.de>
 * @license   LGPL
 * @copyright Fast End Media 2014 <http://www.fast-end-media.de>
 */


/**
 * Run in a custom namespace, so the class can be replaced
 */
namespace Contao;
class ModuleMovieReader extends \ModuleMovie
{
	/**
	 * Template
	 * @var string
	 */
	protected $strTemplate = 'mod_moviereader';

	/**
	 * Display a wildcard in the back end
	 * @return string
	 */
	public function generate()
	{
		if (TL_MODE == 'BE')
		{
			$objTemplate = new \BackendTemplate('be_wildcard');
			$objTemplate->wildcard = '### ' . utf8_strtoupper($GLOBALS['TL_LANG']['FMD']['moviereader'][0]) . ' ###';
			$objTemplate->title = $this->headline;
			$objTemplate->id = $this->id;
			$objTemplate->link = $this->name;
			$objTemplate->href = 'contao/main.php?do=themes&amp;table=tl_module&amp;act=edit&amp;id=' . $this->id;
			return $objTemplate->parse();
		}
		// Set the item from the auto_item parameter
		if (!isset($_GET['items']) && $GLOBALS['TL_CONFIG']['useAutoItem'] && isset($_GET['auto_item']))
		{
			\Input::setGet('items', \Input::get('auto_item'));
		}
		// Do not index or cache the page if no movie item has been specified
		if (!\Input::get('items'))
		{
			global $objPage;
			$objPage->noSearch = 1;
			$objPage->cache = 0;
			return '';
		}

		$this->movie_archives = $this->sortOutProtected(deserialize($this->movie_archives));
		// Do not index or cache the page if there are no archives
		if (!is_array($this->movie_archives) || empty($this->movie_archives))
		{
			global $objPage;
			$objPage->noSearch = 1;
			$objPage->cache = 0;
			return '';
		}
		return parent::generate();
	}

	/**
	 * Generate the module
	 */
	protected function compile()
	{
		global $objPage;
		$this->Template->articles = '';
		$this->Template->referer = 'javascript:history.go(-1)';
		$this->Template->back = $GLOBALS['TL_LANG']['MSC']['goBack'];
		//
		$strUrl = $this->generateFrontendUrl($objPage->row());
		// Get the jumpTo page
		if ($this->jumpTo > 0 && $objPage->id != $this->jumpTo)
		{
			$objJump = \PageModel::findByPk($this->jumpTo);
			if ($objJump !== null)
			{
				$strUrl = $this->generateFrontendUrl($objJump->row(), '/category/%s');
			}
		}
		// Get the movie item
		$objArticle = \MovieModel::findPublishedByParentAndIdOrAlias(\Input::get('items'), $this->movie_archives);
		if ($objArticle === null)
		{
			// Do not index or cache the page
			$objPage->noSearch = 1;
			$objPage->cache = 0;

			// Send a 404 header
			header('HTTP/1.1 404 Not Found');
			$this->Template->articles = '<p class="error">' . sprintf($GLOBALS['TL_LANG']['MSC']['invalidPage'], \Input::get('items')) . '</p>';
			return;
		}
		$arrArticle = $this->parseArticle($objArticle);
		$this->Template->articles = $arrArticle;

		// Overwrite the page title (see #2853 and #4955)
		if ($objArticle->name != '')
		{
			$objPage->pageTitle = strip_tags(strip_insert_tags($objArticle->name.': '.$objPage->pageTitle));
		}

		// Overwrite the page description
    $metaDescription = $objArticle->name;

		if ($objArticle->actor)
		{
			$strGenre = \MovieGenreModel::findPublishedByIdOrAlias($objArticle->genre)->name;
	    $objActor = \MovieActorModel::findMultipleByIds($objArticle->actor);
			$i = 0;
			foreach($objActor AS $actor) {
				$i++;
	      $strActor .= $actor->name.' ';
				if($i >= 3) { break; }
			}

			$metaDescription .= ' ('.$strGenre.') von '.$objArticle->year.' mit den Schauspielern '.$strActor;
		}

		if ($objArticle->teaser != '')
		{
			$metaDescription .= ' - '.$objArticle->teaser;
		}

    $objPage->description = $this->prepareMetaDescription($metaDescription);

		// HOOK: comments extension required
		if ($objArticle->noComments || !in_array('comments', $this->Config->getActiveModules()))
		{
			$this->Template->allowComments = false;
			return;
		}

		$objArchive = $objArticle->getRelated('pid');
		$this->Template->allowComments = $objArchive->allowComments;

		// Comments are not allowed
		if (!$objArchive->allowComments)
		{
			return;
		}

		// Adjust the comments headline level
		$intHl = min(intval(str_replace('h', '', $this->hl)), 5);
		$this->Template->hlc = 'h' . ($intHl + 1);
		$this->import('Comments');
		$arrNotifies = array();

		// Notify the system administrator
		if ($objArchive->notify != 'notify_author')
		{
			$arrNotifies[] = $GLOBALS['TL_ADMIN_EMAIL'];
		}

		// Notify the author
		if ($objArchive->notify != 'notify_admin')
		{
			if (($objAuthor = $objArticle->getRelated('author')) !== null && $objAuthor->email != '')
			{
				$arrNotifies[] = $objAuthor->email;
			}
		}

		$objConfig = new \stdClass();
		$objConfig->perPage = $objArchive->perPage;
		$objConfig->order = $objArchive->sortOrder;
		$objConfig->template = $this->com_template;
		$objConfig->requireLogin = $objArchive->requireLogin;
		$objConfig->disableCaptcha = $objArchive->disableCaptcha;
		$objConfig->bbcode = $objArchive->bbcode;
		$objConfig->moderate = $objArchive->moderate;
		$this->Comments->addCommentsToTemplate($this->Template, $objConfig, 'tl_movie', $objArticle->id, $arrNotifies);
	}
}
